translate.misc.typecheck.Not

Package translate :: Package misc :: Package typecheck :: Class Not |
[hide private]
[frames] | no frames]

# Class Not

source code

Instance Methods | [hide private]
__init__(self, first_type, *types) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__typecheck__(self, func, to_check) | source code
Inherited from `_Boolean`: `__eq__`, `__hash__` Inherited from `CheckType`: `__ne__`, `__repr__`, `__str__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `CheckType`: `__typesig__`

Class Variables | [hide private]
| name = ``'``Not``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, first_type, *types) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __typecheck__(self, func, to_check) | source code
Overrides: CheckType.__typecheck__